import * as ts from "typescript";
import { Path, Resolver } from "../interfaces";
export default class Input {
    private resolver;
    private entries;
    constructor(resolver: Resolver);
    fileExists(path: string): boolean;
    directoryExists(path: string): boolean;
    /**
     * Used for type resolution.
     *
     * Will merge the view of input path and root path.
     */
    getDirectories(path: string): string[];
    /**
     * Used by config parser for matching input.
     *
     * Unlike getDirectories which merges the view of input node and root.
     * We only allow this to return entries for things within the
     * broccoli input node.
     */
    getFileSystemEntries(path: string): ts.FileSystemEntries;
    readFile(path: string): string | undefined;
    relativePath(path: string): string | undefined;
    realpath(path: string): Path | undefined;
    reset(): void;
    private resolve(path);
    private readdir(path);
}
declare module "typescript" {
    interface FileSystemEntries {
        files: string[];
        directories: string[];
    }
    function matchFiles(path: string, extensions: string[], excludes: string[], includes: string[], useCaseSensitiveFileNames: boolean, currentDirectory: string, getFileSystemEntries: (path: string) => FileSystemEntries): string[];
}
